@@ -140,7 +140,7 @@
 #'  \item{P.alpha.Xi}{Individual's posterior probability}
 #'  \item{alpha.P}{Individuals' marginal mastery probabilities matrix}
 #'  \item{P.alpha}{Attribute prior weights for calculating marginalized likelihood in the last iteration}
-#'  \item{model.fit}{Some basic model-fit indeces, including \code{Deviance}, \code{npar}, \code{AIC}, \code{BIC}. @seealso \code{\link[Qval]{fit}}}
+#'  \item{model.fit}{Some basic model-fit indices, including \code{Deviance}, \code{npar}, \code{AIC}, \code{BIC}. @seealso \code{\link[Qval]{fit}}}
 #'  \item{arguments}{A list containing all input arguments}
 #' }
 #' 
@@ -254,7 +254,6 @@
 #'
 #' @importFrom plyr llply
 #' @importFrom nloptr slsqp
-#' @importFrom Matrix drop0
 #'
 
 CDM <- function(Y, Q, model="GDINA", method="EM",
@@ -267,7 +266,7 @@ CDM <- function(Y, Q, model="GDINA", method="EM",
     stop("model must be 'GDINA' when 'BM' !!! \n")
   
   CDMcall <- match.call()
-
+  
   Y <- as.matrix(Y)
   Q <- as.matrix(Q)
   N <- nrow(Y)
@@ -295,7 +294,7 @@ CDM <- function(Y, Q, model="GDINA", method="EM",
     alpha <- KS[apply(P.alpha.Xi, 1, which.max), ]
   }
   if(method == "BM"){
-    options('nloptr.show.inequality.warning'=FALSE)
+    oopts <- options('nloptr.show.inequality.warning' = FALSE)
     item.prior = NULL;  mono.constraint = mono.constraint;
     conv.crit = 1e-4; maxitr = maxitr; bound = 1e-4
     Ki <- rowSums(Q)
@@ -358,8 +357,8 @@ CDM <- function(Y, Q, model="GDINA", method="EM",
 
           obj <- function(x0){-1*sum(Rj*log(x0)+(Nj-Rj)*log(1-x0))-sum(r1*log(x0)+r2*log(1-x0))}
           dev <- function(x0){-1*(Rj + r1 - (Nj + n) * x0)/(x0-x0^2)}
-          ineq <- function(x0){c(ConstrMatrix[[i]] %*% x0)}
-          ineq.jac <- function(x0){ConstrMatrix[[i]]}
+          ineq <- function(x0){-c(ConstrMatrix[[i]] %*% x0)}
+          ineq.jac <- function(x0){-ConstrMatrix[[i]]}
           x00 <- item.parm[i, 1:(2^Ki[i])]
 
           x00[x00<bound] <- bound
@@ -367,7 +366,8 @@ CDM <- function(Y, Q, model="GDINA", method="EM",
 
           optims <- try(slsqp(x0 = x00,fn=obj, gr = dev, hin=ineq,
                                       hinjac = ineq.jac, lower = rep(bound,length(x00)),
-                                      upper = rep(1-bound,length(x00))),silent = TRUE)
+                                      upper = rep(1-bound,length(x00)), deprecatedBehavior = FALSE), 
+                        silent = TRUE)
 
           if(inherits(optims,"try-error")){
             warning(paste("Optimization failed for item", i),call. = FALSE)
@@ -420,6 +420,8 @@ CDM <- function(Y, Q, model="GDINA", method="EM",
     alpha <- KS[apply(P.alpha.Xi, 1, which.max), ]
     if(verbose != 0)
       cat("\n")
+  
+    on.exit(options(oopts))
   }
   
   modelfit <- c(Deviance=CDM.obj$testfit$Deviance,
