@@ -54,15 +54,15 @@
 #' set.seed(123)
 #' 
 #' ## generate Q-matrix and data
-#' K <- 3
+#' K <- 4
 #' I <- 20
 #' Q <- sim.Q(K, I)
 #' IQ <- list(
-#'   P0 = runif(I, 0.0, 0.2),
-#'   P1 = runif(I, 0.8, 1.0)
+#'   P0 = runif(I, 0.0, 0.3),
+#'   P1 = runif(I, 0.7, 0.9)
 #' )
 #' 
-#' model <- "DINA"
+#' model <- "GDINA"
 #' data <- sim.data(Q = Q, N = 500, IQ = IQ, model = model, distribute = "horder")
 #'
 #' ## calculate beta directly
@@ -75,12 +75,9 @@
 #' print(beta)
 #' }
 #'
-#' @export
-#' @importFrom GDINA attributepattern
-#' 
 #' 
 #' @export
-#' @importFrom GDINA attributepattern
+#' @importFrom GDINA attributepattern personparm
 #'
 #'
 get.beta <- function(Y = NULL, Q = NULL, CDM.obj = NULL, model = "GDINA"){
@@ -89,6 +86,8 @@ get.beta <- function(Y = NULL, Q = NULL, CDM.obj = NULL, model = "GDINA"){
     stop("one of [CDM.obj)] and [Y and Q] must not be NULL !!!")
   
   if(!is.null(Q)){
+    Y <- as.matrix(Y)
+    Q <- as.matrix(Q)
     I <- nrow(Q)
     K <- ncol(Q)
     L <- 2^K
