@@ -84,6 +84,8 @@ get.PVAF <- function(Y = NULL, Q = NULL, CDM.obj = NULL, model = "GDINA"){
     stop("one of [CDM.obj)] and [Y and Q] must not be NULL !!!")
 
   if(!is.null(Q)){
+    Y <- as.matrix(Y)
+    Q <- as.matrix(Q)
     I <- nrow(Q)
     K <- ncol(Q)
     L <- 2^K
