@@ -86,6 +86,8 @@ get.priority <- function(Y = NULL, Q = NULL, CDM.obj = NULL, model="GDINA") {
     stop("One of [CDM.obj] and [Y, Q] must not be NULL !!!")
   
   if (!is.null(Q)) {
+    Y <- as.matrix(Y)
+    Q <- as.matrix(Q)
     I <- nrow(Q)
   } else {
     Y <- CDM.obj$analysis.obj$Y
