@@ -95,6 +95,8 @@ get.R2 <- function(Y = NULL, Q = NULL, CDM.obj = NULL, model = "GDINA") {
   
   # Initialize dimensions and variables
   if (!is.null(Q)) {
+    Y <- as.matrix(Y)
+    Q <- as.matrix(Q)
     I <- nrow(Q)
     K <- ncol(Q)
     L <- 2^K
