@@ -10,7 +10,7 @@ get.MLR <- function(alpha.P, Y.i, q.vector) {
 
   formula <- paste("Y ~", paste(names(data)[-length(names(data))], collapse = " + "))
 
-  MLR <- glm(as.formula(formula), data = data, family = "binomial")
+  suppressWarnings(MLR <- glm(as.formula(formula), data = data, family = "binomial"))
   coeffs <- summary(MLR)$coefficients
   r <- coeffs[-1, 1]
   p <- coeffs[-1, 4]
