@@ -343,7 +343,7 @@
 #' @param maxitr Number of max iterations. Default = \code{1}.
 #' @param eps Cut-off points of \eqn{PVAF}, will work when the method is \code{"GDI"} or \code{"Wald"}.
 #'            Default = \code{0.95}. When \code{eps = 'logit'}, the predicted eps by Najera et al. (2019) will be used. See details.
-#' @param alpha.level alpha level for the wald test. Default = \code{0.05}
+#' @param alpha.level alpha level for the wald test. Default = \code{0.05} for \code{"Wald"} and \code{0.01} for \code{"MLR-B"}
 #' @param criter The kind of fit-index value. When \code{method = "Hull"}, it can be \code{R2} for 
 #'               \eqn{R_{McFadden}^2} @seealso \code{\link[Qval]{get.R2}} or \code{'PVAF'} for the proportion of 
 #'               variance accounted for (\eqn{PVAF}) @seealso \code{\link[Qval]{get.PVAF}}. When 
@@ -576,7 +576,7 @@
 validation <- function(Y, Q, 
                        CDM.obj=NULL, par.method="EM", mono.constraint=TRUE, model="GDINA", 
                        method="GDI", search.method="PAA", iter.level="no", maxitr=1,
-                       eps=0.95, alpha.level=0.05, criter = NULL, verbose = TRUE){
+                       eps=0.95, alpha.level=NULL, criter = NULL, verbose = TRUE){
   
   validationCall <- match.call()
   
@@ -613,7 +613,8 @@ validation <- function(Y, Q,
                                   search.method=search.method, maxitr=maxitr, iter.level=iter.level, criter=criter, verbose=verbose)
     }else if(method == "MLR-B"){
       Qval.obj <- validation.MLR(Y, Q, CDM.obj, method=par.method, mono.constraint=mono.constraint, model=model, 
-                                 search.method=search.method, iter.level=iter.level, maxitr=maxitr, verbose=verbose)
+                                 search.method=search.method, iter.level=iter.level, maxitr=maxitr, alpha.level=alpha.level, 
+                                 verbose=verbose)
     }else if(method == "beta"){
       Qval.obj <- validation.beta(Y, Q, CDM.obj, method=par.method, mono.constraint=mono.constraint, model=model, 
                                   search.method=search.method, maxitr=maxitr, iter.level=iter.level, criter=criter, verbose=verbose)
@@ -649,7 +650,7 @@ validation <- function(Y, Q,
 check.validation <- function(Y, Q, 
                              CDM.obj=NULL, par.method="EM", mono.constraint=TRUE, model="GDINA", 
                              method="GDI", search.method="PAA", iter.level="test", maxitr=1,
-                             eps=0.95, alpha.level=0.05, criter = NULL, verbose = TRUE){
+                             eps=0.95, alpha.level=NULL, criter = NULL, verbose = TRUE){
   
   if(!class(Y)[1] %in% c("matrix", "data.frame"))
     stop("Y must be a matrix or data.frame")
@@ -677,6 +678,21 @@ check.validation <- function(Y, Q,
   if (!method %in% c("GDI", "Wald", "Hull", "MLR-B", "beta"))
     stop("method must be one of c('GDI', 'Wald', 'Hull', 'MLR-B', 'beta')!")
   
+  # Set default alpha.level if NULL
+  if(method == "MLR-B" | method == "Wald"){
+    alpha.level <- ifelse(is.null(alpha.level),
+                     ifelse(method == "MLR-B", 
+                            0.01, ifelse(method == "Wald", 
+                                           0.05, NULL)), alpha.level)
+
+    if(method == "MLR-B" | method == "Wald"){
+      if(!is.null(alpha.level)){
+        if(class(alpha.level)[1] != "numeric")
+          stop("alpha.level must be a numeric or NULL!")
+      }
+    }
+  }
+  
   # Set default criter if NULL
   if(method == "beta" | method == "Hull"){
     criter <- ifelse(is.null(criter),
