@@ -14,7 +14,7 @@
 #'              \code{"ACDM"}, \code{"LLM"}, or \code{"rRUM"}. Default = \code{"GDINA"}.
 #'
 #' @return
-#' An object of class \code{list}. The list contains various fit indices:
+#' An object of class \code{fit}. The \code{fit} contains various fit indices:
 #' \describe{
 #'  \item{npar}{The number of parameters.}
 #'  \item{-2LL}{The Deviance.}
@@ -24,6 +24,7 @@
 #'  \item{SABIC}{The Sample-size Adjusted BIC.}
 #'  \item{M2}{A vector consisting of \eqn{M_2} statistic, degrees of freedom, significance level, and \eqn{RMSEA_2} (Liu, Tian, & Xin, 2016).}
 #'  \item{SRMSR}{The standardized root mean squared residual (SRMSR; Ravand & Robitzsch, 2018).}
+#'  \item{arguments}{A list containing all input arguments}
 #' }
 #'
 #' @author
@@ -68,6 +69,8 @@ fit <- function(Y, Q, model="GDINA"){
   if(model == "LCDM")
     stop("Sorry! When model = 'GDINA', fit is not provided temporarily.")
   
+  fitcall <- match.call()
+  
   GDINA.obj <- GDINA(Y, Q, model)
   cat("\n")
   testfit <- modelfit(GDINA.obj)
@@ -82,9 +85,15 @@ fit <- function(Y, Q, model="GDINA"){
   M2 <- c(testfit$M2, testfit$M2.df, testfit$M2.pvalue, testfit$RMSEA2)
   names(M2) <- c("M2", "df", "p.value", "RMSEA2")
   fit.index <- list(npar, testfit$Deviance, testfit$AIC, testfit$BIC, testfit$CAIC, testfit$SABIC,
-                 M2, testfit$SRMSR)
+                 M2, testfit$SRMSR, call = fitcall, 
+                 arguments = list(
+                   Y=Y, Q=Q, model=model
+                 ))
   names(fit.index) <- c("npar", 
                         "-2LL", "AIC", "BIC", "CAIC", "SABIC",
-                        "M2", "SRMSR")
+                        "M2", "SRMSR", "call", "arguments")
+  
+  class(fit.index) <- "fit"
+  
   return(fit.index)
 }
